@@ -5,7 +5,7 @@ with 'Net::Google::DataAPI::Role::Auth';
 use Net::OAuth2::Client;
 use Net::OAuth2::Profile::WebServer;
 use HTTP::Request::Common;
-our $VERSION = '0.03';
+our $VERSION = '0.01';
 
 has [qw(client_id client_secret)] => (is => 'ro', isa => 'Str', required => 1);
 has redirect_uri => (is => 'ro', isa => 'Str', default => 'urn:ietf:wg:oauth:2.0:oob');
@@ -39,9 +39,8 @@ has access_token => (is => 'rw', isa => 'Net::Google::DataAPI::Types::OAuth2::Ac
 
 sub authorize_url {
     my $self = shift;
-    return $self->oauth2_webserver->authorize(
-        scope => join(' ', $self->scope),
-        @_
+    return $self->oauth2_webserver->authorize_url(
+        scope => join(' ', $self->scope)
     );
 }
 
@@ -124,13 +123,6 @@ Net::Google::DataAPI::Auth::OAuth2 - OAuth2 support for Google Data APIs
   );
   my $url = $oauth2->authorize_url();
 
-  # you can add optional parameters:
-  #
-  #   my $url = $oauth2->authorize_url(
-  #     access_type => 'offline',
-  #     approval_prompt => 'force',
-  #   );
-
   # show the user $url and get $code
   # if you're making web app, you will do:
   #
@@ -184,7 +176,7 @@ See L<https://developers.google.com/accounts/docs/OAuth2> for details.
 
 =head1 AUTHOR
 
-Nobuo Danjou E<lt>danjou@soffritto.orgE<gt>
+Nobuo Danjou E<lt>nobuo.danjou@gmail.comE<gt>
 
 =head1 SEE ALSO
 
